Simple Tables Example
===============================================================================

:download:`simple_tables.enaml <../../../examples/components/simple_tables.enaml>`

.. literalinclude:: ../../../examples/components/simple_tables.enaml
    :language: python

::

 $ enaml-run simple_tables.enaml

.. image:: images/simple_tables.png
